CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
87 lines
2.6 KiB
C++
87 lines
2.6 KiB
C++
/*
|
|
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
|
|
*
|
|
* SPDX-License-Identifier: MIT
|
|
*/
|
|
|
|
#include <hip_test_common.hh>
|
|
|
|
#if defined(__HIP_PLATFORM_AMD__) || CUDA_VERSION < CUDA_12000
|
|
|
|
texture<float, 1, hipReadModeElementType> tex;
|
|
|
|
HIP_TEST_CASE(Unit_hipTexRefSetAddress_Basic) {
|
|
CHECK_IMAGE_SUPPORT
|
|
hipDeviceptr_t device_ptr;
|
|
hipModule_t module = nullptr;
|
|
hipTexRef tex_ref = nullptr;
|
|
float* tex_buffer = nullptr;
|
|
size_t offset = 0, tex_size = sizeof(float);
|
|
|
|
HIP_CHECK(hipFree(nullptr));
|
|
HIP_CHECK(hipModuleLoad(&module, "tex_ref_get_module.code"));
|
|
HIP_CHECK(hipModuleGetTexRef(&tex_ref, module, "tex"));
|
|
HIP_CHECK(hipMalloc(&tex_buffer, sizeof(float)));
|
|
HIP_CHECK(hipTexRefSetAddress(&offset, tex_ref, reinterpret_cast<hipDeviceptr_t>(tex_buffer),
|
|
tex_size));
|
|
HIP_CHECK(hipTexRefGetAddress(&device_ptr, tex_ref));
|
|
|
|
REQUIRE(reinterpret_cast<void*>(device_ptr) != nullptr);
|
|
HIP_CHECK(hipModuleUnload(module));
|
|
HIP_CHECK(hipFree(tex_buffer));
|
|
}
|
|
|
|
HIP_TEST_CASE(Unit_hipTexRefSetAddress_Positive) {
|
|
CHECK_IMAGE_SUPPORT
|
|
hipModule_t module = nullptr;
|
|
hipTexRef tex_ref = nullptr;
|
|
float* tex_buffer = nullptr;
|
|
size_t offset = 0, tex_size = sizeof(float);
|
|
|
|
HIP_CHECK(hipFree(nullptr));
|
|
HIP_CHECK(hipModuleLoad(&module, "tex_ref_get_module.code"));
|
|
HIP_CHECK(hipModuleGetTexRef(&tex_ref, module, "tex"));
|
|
HIP_CHECK(hipMalloc(&tex_buffer, sizeof(float)));
|
|
|
|
SECTION("offset is null") {
|
|
HIP_CHECK(hipTexRefSetAddress(nullptr, tex_ref, reinterpret_cast<hipDeviceptr_t>(tex_buffer),
|
|
tex_size));
|
|
}
|
|
|
|
SECTION("size is 0") {
|
|
HIP_CHECK(
|
|
hipTexRefSetAddress(&offset, tex_ref, reinterpret_cast<hipDeviceptr_t>(tex_buffer), 0));
|
|
}
|
|
|
|
HIP_CHECK(hipModuleUnload(module));
|
|
HIP_CHECK(hipFree(tex_buffer));
|
|
}
|
|
|
|
HIP_TEST_CASE(Unit_hipTexRefSetAddress_Negative) {
|
|
CHECK_IMAGE_SUPPORT
|
|
hipModule_t module = nullptr;
|
|
hipTexRef tex_ref = nullptr;
|
|
float* tex_buffer = nullptr;
|
|
size_t offset = 0, tex_size = sizeof(float);
|
|
|
|
HIP_CHECK(hipFree(nullptr));
|
|
HIP_CHECK(hipModuleLoad(&module, "tex_ref_get_module.code"));
|
|
HIP_CHECK(hipModuleGetTexRef(&tex_ref, module, "tex"));
|
|
HIP_CHECK(hipMalloc(&tex_buffer, sizeof(float)));
|
|
|
|
#if HT_AMD
|
|
HIP_CHECK_ERROR(
|
|
hipTexRefSetAddress(&offset, nullptr, reinterpret_cast<hipDeviceptr_t>(tex_buffer), tex_size),
|
|
hipErrorInvalidValue);
|
|
#else
|
|
HIP_CHECK_ERROR(
|
|
hipTexRefSetAddress(&offset, nullptr, reinterpret_cast<hipDeviceptr_t>(tex_buffer), tex_size),
|
|
hipErrorInvalidResourceHandle);
|
|
#endif
|
|
|
|
HIP_CHECK(hipModuleUnload(module));
|
|
HIP_CHECK(hipFree(tex_buffer));
|
|
}
|
|
|
|
#endif
|